==> umbrello-debuginfo-17.08.3-1.tar.xz: usr/src/debug/umbrello-17.08.3-1/umbrello/CMakeFiles/libumbrello.dir/qrc_ui.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/umbrello/umbrello-17.08.3-1.i686/build/umbrello/umbrelloui.rc
  0x0,0x0,0x3,0x1f,
  0x0,
  0x0,0xd,0x54,0x78,0x9c,0x95,0x97,0x4b,0x6f,0xdb,0x30,0xc,0xc7,0xef,0xfd,0x14,
  0x9e,0xf,0xbb,0x6,0x1b,0xb0,0xd3,0xd2,0x2,0x5d,0xdb,0xed,0xd2,0x3d,0x80,0x16,
  0x18,0xb6,0x8b,0x41,0x5b,0x8c,0xad,0x56,0xaf,0x4a,0x72,0x1e,0xfd,0xf4,0xa3,0x1d,
  0x37,0xb1,0x62,0xc7,0xf2,0x72,0x89,0xcd,0xfc,0x48,0x51,0x12,0xf9,0x97,0xb2,0x7c,
  0x77,0xfb,0xf3,0xe6,0xf1,0xcf,0xaf,0xbb,0xe4,0xd9,0x80,0xf5,0x65,0xcd,0xaf,0x2e,
  0x96,0x6f,0x8f,0x89,0x2,0x89,0x97,0x69,0x2d,0x73,0x8b,0x42,0xe8,0x34,0x59,0xa3,
  0x75,0x5c,0xab,0xcb,0xf4,0xc3,0xc7,0x94,0xb8,0xef,0xa8,0xea,0x2f,0x60,0xaf,0x2e,
  0x92,0xa4,0x7d,0xee,0xf8,0x15,0x17,0x98,0x5e,0x2d,0x3d,0x6e,0xfd,0xd5,0x7b,0x90,
  0xe6,0xf3,0x57,0x32,0x2c,0x17,0xed,0x3b,0xa1,0xcd,0xe7,0x14,0xcf,0x70,0x6b,0xb4,
  0xf5,0x81,0xd7,0x5d,0x6b,0x4a,0xa4,0x66,0x28,0x42,0xef,0x36,0xc2,0x75,0xe1,0x29,
  0x95,0x61,0x8c,0x8c,0xe9,0x22,0xd7,0xfa,0x39,0x5d,0xcc,0xc3,0xb7,0x95,0x97,0xe2,
  0x8,0x2f,0x17,0x4d,0x6a,0x87,0xb7,0xc0,0x6d,0xcd,0x71,0xf3,0xe6,0xc6,0x25,0x94,
  0xe8,0xf6,0x7e,0x47,0x9f,0xfe,0xbc,0x90,0xf1,0x93,0x9,0x91,0xa1,0x3f,0x91,0x30,
  0x38,0xcd,0x12,0x3d,0x66,0x8e,0xbe,0xa,0x8f,0x6c,0x2a,0x72,0x93,0x87,0xb,0x42,
  0xdf,0x72,0x28,0x2d,0xc8,0x20,0x7a,0xcf,0x41,0x51,0xde,0x8d,0x53,0xe0,0xf3,0x3,
  0x37,0x27,0x9b,0x12,0xe4,0xd3,0xf8,0x14,0x2,0x9c,0xcb,0xd8,0x3e,0xf8,0x71,0x8d,
  0xce,0xf2,0xe,0x5f,0x6a,0x54,0x5,0xe,0x5d,0x46,0x62,0x6b,0x21,0x20,0xd7,0x16,
  0x1a,0xfb,0x1c,0x87,0xda,0x61,0x56,0x80,0x9b,0x15,0xdc,0x79,0xf0,0xb3,0x40,0x20,
  0xc3,0x9a,0xfb,0xdd,0xbc,0x8c,0xa5,0xd1,0xa,0x95,0x9f,0x3,0x33,0x34,0x42,0xef,
  0xe4,0x4c,0x9a,0x30,0x4a,0x82,0xba,0xac,0x5d,0xd,0x57,0x71,0x73,0xea,0xd5,0xaf,
  0xcb,0x91,0xaa,0x2c,0x4,0x82,0x1d,0xf8,0xc,0xb9,0x7d,0x95,0x4d,0x0,0xfd,0xf2,
  0x3e,0x60,0xf,0x48,0x8a,0x0,0x5e,0xdb,0xc5,0xb0,0xb6,0x5c,0xa5,0xc3,0xe2,0x7a,
  0xa8,0xda,0xf2,0xd2,0xe3,0xd5,0x75,0xcf,0x9d,0xef,0x8f,0x27,0xe8,0x3d,0x4d,0xc6,
  0x26,0xd9,0x1b,0xe3,0x55,0x6b,0x99,0xd1,0x5a,0xd6,0x41,0x1,0xff,0x25,0x6b,0x50,
  0xf1,0x67,0xbc,0x41,0xf0,0x52,0xd,0xdd,0xaf,0x1b,0xf3,0x54,0x7,0xec,0xfd,0x4,
  0xae,0x8e,0x9,0x8e,0x23,0x96,0x97,0x55,0x8c,0xf1,0xda,0x44,0x88,0x5c,0x7b,0xaf,
  0x65,0x4,0x22,0x5,0xf6,0xbc,0x0,0x91,0x49,0xce,0x18,0xc9,0xec,0x34,0x5d,0x69,
  0xcb,0x5f,0xb5,0xf2,0x73,0xf9,0x43,0x74,0x46,0xbb,0x62,0x79,0x5e,0xfb,0xff,0x18,
  0x61,0xc4,0x27,0xd8,0x91,0x41,0x11,0xd,0x8b,0xcf,0x29,0x30,0xb4,0x52,0x59,0x69,
  0x39,0x9b,0xa8,0xd1,0xb6,0xe4,0x22,0x8c,0xb1,0xda,0x34,0xb3,0x39,0xd5,0xe8,0x13,
  0x29,0x2d,0xe8,0x74,0x9,0xaa,0xe2,0x86,0xc,0xe7,0x45,0x9a,0xcb,0xb6,0x3b,0x5a,
  0x5d,0x1c,0x1f,0xbc,0x23,0x68,0xf8,0x27,0xd2,0xf1,0x29,0x86,0xab,0x32,0xdb,0xf0,
  0x57,0xb0,0x67,0xa6,0x51,0xa2,0xc2,0x4e,0x1d,0x67,0x60,0x98,0x81,0x38,0x1c,0x63,
  0x41,0xf5,0x37,0xa,0x87,0x99,0x0,0x1a,0xae,0xdf,0x3,0xd7,0xad,0x3d,0x69,0x27,
  0x7d,0x4f,0x3f,0xd6,0xd4,0xf0,0x53,0xdd,0xe0,0xd0,0x37,0x58,0xab,0x98,0x24,0x51,
  0x85,0xe5,0xc6,0x9f,0x93,0xb4,0x3,0xcb,0x20,0x86,0x14,0xc6,0x44,0x11,0x57,0x81,
  0x8d,0x52,0x2c,0x6,0x70,0x26,0x62,0xc8,0x13,0xac,0xa3,0x9,0x37,0xcc,0xbc,0xd9,
  0xcb,0x9d,0x7b,0x89,0xe,0x69,0x28,0x18,0xc4,0x29,0xb4,0x71,0xa6,0x8a,0xae,0x11,
  0x21,0x9f,0xa2,0x8c,0x76,0xbe,0xb4,0x38,0x27,0xf5,0x9d,0xaf,0xb4,0x8a,0x51,0xb6,
  0xce,0x77,0x31,0xc6,0x17,0xd1,0xc1,0xd6,0x20,0xa2,0x5b,0xb3,0x95,0xc2,0x15,0x15,
  0x4a,0x18,0x3d,0x34,0xa7,0xf5,0xa7,0xb0,0xd8,0x5e,0x19,0x70,0x5,0xb5,0xa0,0x33,
  0x1b,0xe8,0x6,0xb1,0x33,0x78,0xa6,0xcb,0xf7,0x17,0xa3,0x7e,0x5b,0x8e,0xdf,0xd4,
  0x28,0xb3,0xa6,0xcf,0xc3,0xcb,0xda,0x43,0x67,0xc,0x64,0xe6,0x16,0x57,0x5c,0xe1,
  0x37,0xab,0x6b,0x73,0x2a,0x75,0x69,0x2,0xc6,0xa0,0x62,0x7d,0x53,0x44,0x1c,0xbd,
  0xc5,0xa9,0x43,0xbe,0x65,0xe8,0x9e,0x1c,0x43,0x6a,0xc5,0x74,0x8c,0xc9,0xf9,0x39,
  0x65,0x3a,0x32,0xce,0xa3,0x45,0x3d,0xb1,0x9e,0xbd,0xac,0xf6,0x57,0x98,0x28,0xa7,
  0xf3,0x46,0x5f,0xa3,0xd8,0x6,0x5,0x5d,0xdb,0x30,0xdc,0xa3,0xfd,0x77,0xfb,0xcf,
  0x65,0xf9,0xa8,0xb5,0xa0,0xa7,0xce,0x51,0x2,0x57,0x9d,0x25,0x4d,0x56,0xb5,0x10,
  0xbf,0x39,0xf3,0xd5,0x65,0xea,0x6d,0x4d,0xa7,0x1a,0xdd,0xd4,0x4,0x6d,0x52,0xf7,
  0xda,0xc4,0xe9,0xd8,0xe6,0xf1,0xf8,0xff,0xe9,0x1f,0x20,0x77,0x3f,0xe7,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // umbrello
  0x0,0x8,
  0x3,0x98,0xcc,0xaf,
  0x0,0x75,
  0x0,0x6d,0x0,0x62,0x0,0x72,0x0,0x65,0x0,0x6c,0x0,0x6c,0x0,0x6f,
    // umbrelloui.rc
  0x0,0xd,
  0xb,0x18,0xdc,0x3,
  0x0,0x75,
  0x0,0x6d,0x0,0x62,0x0,0x72,0x0,0x65,0x0,0x6c,0x0,0x6c,0x0,0x6f,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/umbrello
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/umbrello/umbrelloui.rc
  0x0,0x0,0x0,0x2c,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0xbb,0x65,0x3c,0xee,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_ui)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_ui)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ui)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ui)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_ui)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ui)(); }
   } dummy;
}

==> umbrello-debuginfo-17.12.3-1.tar.xz: usr/src/debug/umbrello-17.12.3-1/umbrello/CMakeFiles/libumbrello.dir/qrc_ui.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.4
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/umbrello/umbrello-17.12.3-1.x86_64/build/umbrello/umbrelloui.rc
  0x0,0x0,0x3,0x1f,
  0x0,
  0x0,0xd,0x54,0x78,0x9c,0x95,0x97,0x4b,0x6f,0xdb,0x30,0xc,0xc7,0xef,0xfd,0x14,
  0x9e,0xf,0xbb,0x6,0x1b,0xb0,0xd3,0xd2,0x2,0x5d,0xdb,0xed,0xd2,0x3d,0x80,0x16,
  0x18,0xb6,0x8b,0x41,0x5b,0x8c,0xad,0x56,0xaf,0x4a,0x72,0x1e,0xfd,0xf4,0xa3,0x1d,
  0x37,0xb1,0x62,0xc7,0xf2,0x72,0x89,0xcd,0xfc,0x48,0x51,0x12,0xf9,0x97,0xb2,0x7c,
  0x77,0xfb,0xf3,0xe6,0xf1,0xcf,0xaf,0xbb,0xe4,0xd9,0x80,0xf5,0x65,0xcd,0xaf,0x2e,
  0x96,0x6f,0x8f,0x89,0x2,0x89,0x97,0x69,0x2d,0x73,0x8b,0x42,0xe8,0x34,0x59,0xa3,
  0x75,0x5c,0xab,0xcb,0xf4,0xc3,0xc7,0x94,0xb8,0xef,0xa8,0xea,0x2f,0x60,0xaf,0x2e,
  0x92,0xa4,0x7d,0xee,0xf8,0x15,0x17,0x98,0x5e,0x2d,0x3d,0x6e,0xfd,0xd5,0x7b,0x90,
  0xe6,0xf3,0x57,0x32,0x2c,0x17,0xed,0x3b,0xa1,0xcd,0xe7,0x14,0xcf,0x70,0x6b,0xb4,
  0xf5,0x81,0xd7,0x5d,0x6b,0x4a,0xa4,0x66,0x28,0x42,0xef,0x36,0xc2,0x75,0xe1,0x29,
  0x95,0x61,0x8c,0x8c,0xe9,0x22,0xd7,0xfa,0x39,0x5d,0xcc,0xc3,0xb7,0x95,0x97,0xe2,
  0x8,0x2f,0x17,0x4d,0x6a,0x87,0xb7,0xc0,0x6d,0xcd,0x71,0xf3,0xe6,0xc6,0x25,0x94,
  0xe8,0xf6,0x7e,0x47,0x9f,0xfe,0xbc,0x90,0xf1,0x93,0x9,0x91,0xa1,0x3f,0x91,0x30,
  0x38,0xcd,0x12,0x3d,0x66,0x8e,0xbe,0xa,0x8f,0x6c,0x2a,0x72,0x93,0x87,0xb,0x42,
  0xdf,0x72,0x28,0x2d,0xc8,0x20,0x7a,0xcf,0x41,0x51,0xde,0x8d,0x53,0xe0,0xf3,0x3,
  0x37,0x27,0x9b,0x12,0xe4,0xd3,0xf8,0x14,0x2,0x9c,0xcb,0xd8,0x3e,0xf8,0x71,0x8d,
  0xce,0xf2,0xe,0x5f,0x6a,0x54,0x5,0xe,0x5d,0x46,0x62,0x6b,0x21,0x20,0xd7,0x16,
  0x1a,0xfb,0x1c,0x87,0xda,0x61,0x56,0x80,0x9b,0x15,0xdc,0x79,0xf0,0xb3,0x40,0x20,
  0xc3,0x9a,0xfb,0xdd,0xbc,0x8c,0xa5,0xd1,0xa,0x95,0x9f,0x3,0x33,0x34,0x42,0xef,
  0xe4,0x4c,0x9a,0x30,0x4a,0x82,0xba,0xac,0x5d,0xd,0x57,0x71,0x73,0xea,0xd5,0xaf,
  0xcb,0x91,0xaa,0x2c,0x4,0x82,0x1d,0xf8,0xc,0xb9,0x7d,0x95,0x4d,0x0,0xfd,0xf2,
  0x3e,0x60,0xf,0x48,0x8a,0x0,0x5e,0xdb,0xc5,0xb0,0xb6,0x5c,0xa5,0xc3,0xe2,0x7a,
  0xa8,0xda,0xf2,0xd2,0xe3,0xd5,0x75,0xcf,0x9d,0xef,0x8f,0x27,0xe8,0x3d,0x4d,0xc6,
  0x26,0xd9,0x1b,0xe3,0x55,0x6b,0x99,0xd1,0x5a,0xd6,0x41,0x1,0xff,0x25,0x6b,0x50,
  0xf1,0x67,0xbc,0x41,0xf0,0x52,0xd,0xdd,0xaf,0x1b,0xf3,0x54,0x7,0xec,0xfd,0x4,
  0xae,0x8e,0x9,0x8e,0x23,0x96,0x97,0x55,0x8c,0xf1,0xda,0x44,0x88,0x5c,0x7b,0xaf,
  0x65,0x4,0x22,0x5,0xf6,0xbc,0x0,0x91,0x49,0xce,0x18,0xc9,0xec,0x34,0x5d,0x69,
  0xcb,0x5f,0xb5,0xf2,0x73,0xf9,0x43,0x74,0x46,0xbb,0x62,0x79,0x5e,0xfb,0xff,0x18,
  0x61,0xc4,0x27,0xd8,0x91,0x41,0x11,0xd,0x8b,0xcf,0x29,0x30,0xb4,0x52,0x59,0x69,
  0x39,0x9b,0xa8,0xd1,0xb6,0xe4,0x22,0x8c,0xb1,0xda,0x34,0xb3,0x39,0xd5,0xe8,0x13,
  0x29,0x2d,0xe8,0x74,0x9,0xaa,0xe2,0x86,0xc,0xe7,0x45,0x9a,0xcb,0xb6,0x3b,0x5a,
  0x5d,0x1c,0x1f,0xbc,0x23,0x68,0xf8,0x27,0xd2,0xf1,0x29,0x86,0xab,0x32,0xdb,0xf0,
  0x57,0xb0,0x67,0xa6,0x51,0xa2,0xc2,0x4e,0x1d,0x67,0x60,0x98,0x81,0x38,0x1c,0x63,
  0x41,0xf5,0x37,0xa,0x87,0x99,0x0,0x1a,0xae,0xdf,0x3,0xd7,0xad,0x3d,0x69,0x27,
  0x7d,0x4f,0x3f,0xd6,0xd4,0xf0,0x53,0xdd,0xe0,0xd0,0x37,0x58,0xab,0x98,0x24,0x51,
  0x85,0xe5,0xc6,0x9f,0x93,0xb4,0x3,0xcb,0x20,0x86,0x14,0xc6,0x44,0x11,0x57,0x81,
  0x8d,0x52,0x2c,0x6,0x70,0x26,0x62,0xc8,0x13,0xac,0xa3,0x9,0x37,0xcc,0xbc,0xd9,
  0xcb,0x9d,0x7b,0x89,0xe,0x69,0x28,0x18,0xc4,0x29,0xb4,0x71,0xa6,0x8a,0xae,0x11,
  0x21,0x9f,0xa2,0x8c,0x76,0xbe,0xb4,0x38,0x27,0xf5,0x9d,0xaf,0xb4,0x8a,0x51,0xb6,
  0xce,0x77,0x31,0xc6,0x17,0xd1,0xc1,0xd6,0x20,0xa2,0x5b,0xb3,0x95,0xc2,0x15,0x15,
  0x4a,0x18,0x3d,0x34,0xa7,0xf5,0xa7,0xb0,0xd8,0x5e,0x19,0x70,0x5,0xb5,0xa0,0x33,
  0x1b,0xe8,0x6,0xb1,0x33,0x78,0xa6,0xcb,0xf7,0x17,0xa3,0x7e,0x5b,0x8e,0xdf,0xd4,
  0x28,0xb3,0xa6,0xcf,0xc3,0xcb,0xda,0x43,0x67,0xc,0x64,0xe6,0x16,0x57,0x5c,0xe1,
  0x37,0xab,0x6b,0x73,0x2a,0x75,0x69,0x2,0xc6,0xa0,0x62,0x7d,0x53,0x44,0x1c,0xbd,
  0xc5,0xa9,0x43,0xbe,0x65,0xe8,0x9e,0x1c,0x43,0x6a,0xc5,0x74,0x8c,0xc9,0xf9,0x39,
  0x65,0x3a,0x32,0xce,0xa3,0x45,0x3d,0xb1,0x9e,0xbd,0xac,0xf6,0x57,0x98,0x28,0xa7,
  0xf3,0x46,0x5f,0xa3,0xd8,0x6,0x5,0x5d,0xdb,0x30,0xdc,0xa3,0xfd,0x77,0xfb,0xcf,
  0x65,0xf9,0xa8,0xb5,0xa0,0xa7,0xce,0x51,0x2,0x57,0x9d,0x25,0x4d,0x56,0xb5,0x10,
  0xbf,0x39,0xf3,0xd5,0x65,0xea,0x6d,0x4d,0xa7,0x1a,0xdd,0xd4,0x4,0x6d,0x52,0xf7,
  0xda,0xc4,0xe9,0xd8,0xe6,0xf1,0xf8,0xff,0xe9,0x1f,0x20,0x77,0x3f,0xe7,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // umbrello
  0x0,0x8,
  0x3,0x98,0xcc,0xaf,
  0x0,0x75,
  0x0,0x6d,0x0,0x62,0x0,0x72,0x0,0x65,0x0,0x6c,0x0,0x6c,0x0,0x6f,
    // umbrelloui.rc
  0x0,0xd,
  0xb,0x18,0xdc,0x3,
  0x0,0x75,
  0x0,0x6d,0x0,0x62,0x0,0x72,0x0,0x65,0x0,0x6c,0x0,0x6c,0x0,0x6f,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/umbrello
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/umbrello/umbrelloui.rc
  0x0,0x0,0x0,0x2c,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x62,0x26,0xae,0x96,0x88,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_ui)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_ui)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ui)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ui)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_ui)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ui)(); }
   } dummy;
}
